<?php
namespace PME\Controllers\Custo;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class CustoRealizadoGlobalPeriodoController extends \Zeedhi\Framework\Controller\Report {
    protected $birtStrategy;
    protected $newCode;
    protected $lista;
    protected $ConsumoPlanejadoRealizadoController;
    protected $utilities;

    public function __construct(ReportService $reportService, $birtStrategy, $newCode, $lista, $ConsumoPlanejadoRealizadoController, $utilities) {
      $this->birtStrategy  = $birtStrategy;
      $this->newCode       = $newCode;
      $this->lista         = $lista;
      $this->ConsumoPlanejadoRealizadoController = $ConsumoPlanejadoRealizadoController;
      $this->utilities = $utilities;
      
      parent::__construct($reportService);
    }
    
    protected $reportMapping = array (
      'PME01700' => 
      array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
        array (
          "CDTIPOCUSTO"   => "P_NRTIPOCUSTO",
          "TAMACNIVEL"    => "P_NRTAMACNIVEL",
          "ORDENA"        => "P_NRTAMCODIGO",
          "ESTOCAVEIS"    => "P_IDESTOCAVEIS",
          "LISTASERV"     => "P_CDSERVFILI", 
          "DTDE"          => "P_DTINICIAL",
          "DTATE"         => "P_DTFINAL",
          "PRODINICIAL"   => "P_CDPRODUTOINI",
          "PRODFINAL"     => "P_CDPRODUTOFIN",
          "DTMESINIC"     => "P_DTMESINIC",
          "DTMESFINA"     => "P_DTMESFINA",
          "NAOESTOCAVEIS" => "P_IDNESTOCAVEIS",
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "AGRUPMASK"     => "P_MASCAGRUP",
          "CDPICTPROD"    => "P_CDPICTPROD",
          "NMTIPOCUSTO"   => "P_NMTIPOCUSTO",
          "NRORG"         => "P_NRORG"
        )
      ),
      'PME01701' => 
      array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
        array (
          "CDTIPOCUSTO"   => "P_NRTIPOCUSTO",
          "TAMACNIVEL"    => "P_NRTAMACNIVEL",
          "ORDENA"        => "P_NRTAMCODIGO",
          "ESTOCAVEIS"    => "P_IDESTOCAVEIS",
          "LISTASERV"     => "P_CDSERVFILI", 
          "DTDE"          => "P_DTINICIAL",
          "DTATE"         => "P_DTFINAL",
          "PRODINICIAL"   => "P_CDPRODUTOINI",
          "PRODFINAL"     => "P_CDPRODUTOFIN",
          "DTMESINIC"     => "P_DTMESINIC",
          "DTMESFINA"     => "P_DTMESFINA",
          "NAOESTOCAVEIS" => "P_IDNESTOCAVEIS",
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "AGRUPMASK"     => "P_MASCAGRUP",
          "CDPICTPROD"    => "P_CDPICTPROD",
          "NMTIPOCUSTO"   => "P_NMTIPOCUSTO",
          "NRORG"         => "P_NRORG"
        )
      )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      $rows = $request->getRow();
      $nrorg = $this->utilities->getNrOrg();
      
      $rows['NRORG'] = $nrorg;
      
      $cdprodIni = isset($rows['PRODINICIAL']['CDARVPROD']) ? $rows['PRODINICIAL']['CDARVPROD'] : 0;
      if(!(isset($rows['PRODFINAL']['CDARVPROD']))) $cdprodFin = 'zzzzzzzzzzz';
      else $cdprodFin = str_pad($rows['PRODFINAL']['CDARVPROD'], 10, 'z');

      $rows['PRODINICIAL'] = $cdprodIni;
      $rows['PRODFINAL'] = $cdprodFin;
      
      $rows['NRCONSPLAN'] = $this->newCode->getCodeByTableName('CONSPLAN'.$rows['CDFILCENTPME'], $nrorg); //usa na procedure
      
      $newRow = $this->ConsumoPlanejadoRealizadoController->procedure($rows);
      
      //$rows['SERVICO'] = $newRow['SERVICO'];
      $rows['SERVICO_LISTA'] = '';
      if (empty($rows['SERVICO'])) {
        $rows['SERVICO_LISTA'] = $this->ConsumoPlanejadoRealizadoController->getUnidServ($rows);
      } else {
        foreach ($rows['CDSERVFILI'] as $servfili) {
          $rows['SERVICO_LISTA'] .= $servfili['FILISERV'].'_';
        }
      }
      $rows['LISTASERV'] = $this->lista->geraLista($rows['SERVICO_LISTA'], $nrorg);

      /*$unidadeServico = [];
      foreach($rows['SERVICO'] as $row){
        $concatUnidServ = $row['FILISERV'];
        array_push($unidadeServico, $concatUnidServ);
      }
      
      if (empty($rows['SERVICO'])) {
        $unidServ = $this->ConsumoPlanejadoRealizadoController->getUnidServ($rows);
        $rows['LISTASERV'] = $this->lista->geraLista($unidServ, $nrorg);
      } else $rows['LISTASERV'] = $this->lista->geraLista(join("_", $unidadeServico), $nrorg);*/
      
      if($rows['ORDENA'] == 0) $rows['TAMCODIGO'] = 10;
      else $rows['TAMCODIGO'] = 0;
      
      $this->birtStrategy->setReportLocale($this->utilities->getLanguage());
      $this->birtStrategy->setReportFormat(strtolower($rows['reportFormat']));
    }
}